\name{depth.contours}
\alias{distribution.depth.contours}
\alias{sample.depth.contours}
\alias{plot.depth.contours}
\title{Location-Scale Depth Contours}
\description{
  Calculates and plots location-scale depth contours based on Student depth
  for distributions (populations) and samples (data sets).
}

\usage{
   distribution.depth.contours(depth=c(0.1,0.2,0.3,0.4),qdist=function(x){qnorm(x,0,1)}, 
                   pdist=function(x){pnorm(x,0,1)},lengthmu=100,lengthbeta=100)  

  sample.depth.contours(depth=round(c(0.1,0.2,0.3,0.4)*length(y)),y,lengthmu=1000)

  plot.depth.contours(depth.cont,ratio=1,first.plot=T,mu.min=0,mu.max=0)
}

\arguments{
  \item{depth}{numerical vector of depth values in (0,0.5) for distributions,
                      integer vector of depth values within 1 and sample size for samples}
  \item{qdist}{quantile function of the distribution, default is the quantile function 
                     of the standard normal distribution.}
  \item{pdist}{distribution function of the distribution, default is the distribution function
                     of the standard normal distribution.}
  \item{y}{numerical vector of observations (data set)}
  \item{lengthmu}{length of the vector of location parameters for which upper and 
              lower bounds of the contour are calculated. The larger \code{lengthmu} is the 
                 smoother are the contour lines.}
 \item{lengthbeta}{length of the vector for calculating the upper and lower bound for the
                   contour for a given location parameter. The larger \code{lengthbeta} the more 
                      precise are the bounds.}
 \item{depth.cont}{a list given as output of  \code{distribution.depth.contours} or of
                             \code{sample.depth.contours}.}
 \item{ratio}{ratio of the lengths of the location and scale axes.}
 \item{first.plot}{if \code{first.plot=T} (default) a new plot is generated, if \code{first.plot=F} the plot 
           is added to an existing plot.}
\item{mu.min}{minimum value of the location axis. If \code{mu.min==mu.max} (default) 
         then the minimu and maximum value of the location axis is determined by the location 
         vector of the first list component of \code{depth.cont}.}
 \item{mu.max}{maximum value of the location axis. Compare \code{mu.min}.}
}
\details{
  \code{distribution.depth.contours} calculates the upper and lower bounds of
   the depth contours of a distribution (population).

  \code{sample.depth.contours} calculates the  the upper and lower bounds of
   the depth contours of a sample (data set).

  \code{plot.depth.contours} plots the contours given by 
     \code{distribution.depth.contours} or  \code{sample.depth.contours} .
}

\value{
  Return value of  \code{distribution.depth.contours}  and
     \code{sample.depth.contours} is a list. Each component of the list is list
     with the following components: \code{depth} provides the depth,
     \code{cont.exist} a logical value whether a contour for the depth exists. 
     If it is \code{TRUE} then the list has the further components:
     \code{mubound} a vector of location values, \code{lbound} a vector of the
     lower bounds of the scale values and \code{ubound} a vector of of the
     upper bounds of the scale values.

\code{plot.depth.contours} has no return value. 
}

\seealso{\code{\link{distribution.max.depth}}, \code{\link{sample.max.depth}}, 
            \code{\link{distribution.max.depth.line}},  \code{\link{sample.max.depth.line}}}

\examples{

 cauchy.depth.contours<-distribution.depth.contours(qdist=function(x){qt(x,1)},pdist=function(x){pt(x,1)}, lengthmu=1000)
 plot.depth.contours(cauchy.depth.contours)

 y<-rt(100,1)
 y.depth.contours<-sample.depth.contours(y=y,lengthmu=1000)
 plot.depth.contours(y.depth.contours)
 
}

\references{
 Mizera, I. and Mller, C.H. (2003). Location-scale depth.
 }

\author{
  Christine Mller (mueller@math.uni-oldenburg.de)
  }

\keyword{ Student depth }
\keyword{ depth contours }
\keyword{ location-scale }


